<?php

namespace Drupal\vde_drush\FormatManipulator;

/**
 * Removes headers and writes output to file.
 */
class VdeDrushFormatManipulatorBase {

  /**
   * File name.
   *
   * @var string
   */
  protected $fileName;

  /**
   * Total number of rows.
   *
   * @var string
   */
  protected $totalRows;

  /**
   * Number of items per batch.
   *
   * @var string
   */
  protected $itemsPerBatch;

  /**
   * VdeDrushFormatManipulatorBase constructor.
   *
   * @param string $file_name
   *   File name where to write the output string.
   */
  public function __construct($file_name) {
    $this->fileName = $file_name;
  }

  /**
   * Removes headers from file if it's not the first iteration.
   *
   * @param string $content
   *   The output of a view.
   * @param string $export_count
   *   Export count.
   *
   * @return string
   *   Content with removed headers.
   */
  public function removeHeaders($content, $export_count) {
    return $content;
  }

  /**
   * Writes $content to file.
   *
   * @param string $content
   *   Content to put into file.
   *
   * @return bool
   *   TRUE in case of success, FALSE otherwise
   */
  public function writeToFile($content) {
    return (bool) file_put_contents($this->fileName, $content, FILE_APPEND);
  }

  /**
   * Sets $totalRows property.
   *
   * @param string $total_rows
   *   The number of total rows.
   */
  public function setTotalRows($total_rows) {
    $this->totalRows = $total_rows;
  }

  /**
   * Sets $itemsPerBatch property.
   *
   * @param string $items_per_batch
   *   The number of items per batch.
   */
  public function setItemsPerBatch($items_per_batch) {
    $this->itemsPerBatch = $items_per_batch;
  }

}
